@@ -6,7 +6,7 @@ class ErrDefectTypeNotSupported(ErrorBase):
     """Given defect type not supported by method."""
 
 
-class Context:
+class Context(object):
     """Base class for Context of the danger method."""
 
     name = "not defined"
@@ -23,6 +23,16 @@ class Context:
         self.explain_text = []
         self.is_explain = False
 
+    @classmethod
+    def lang(cls, _lang_code):
+        """Load language dict for localize explain text."""
+        raise NotImplementedError("{}.lang".format(cls.__class__.__name__))
+
     def explain(self):
         """Return text with explanation for calculation."""
-        return '\n'.join(self.explain_text)
+        return ''.join(self.explain_text)
+
+    def add_explain(self, msg_list):
+        """Add messages from the list to explain array."""
+        if self.is_explain:
+            self.explain_text.extend(msg_list)
